
# This file was generated by 'versioneer.py' (0.21) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2022-08-03T18:36:50-0700",
 "dirty": false,
 "error": null,
 "full-revisionid": "fc9f3f41bd307a896dc9ee71bd628b8dccffeef6",
 "version": "4.5.3"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
